# Perceptron_pypi
python package indexing for Perceptron implemetation

# How to use 

```python
pip install Perceptron-pypi-vishalbansal-1650
```

# URL for pypi

[Perceptron pypi page](https://pypi.org/project/Perceptron-pypi-vishalbansal-1650/)

# References 

[Python Documentation for pypi](https://packaging.python.org/tutorials/packaging-projects/)


[Offical docs for GitHub Actions](https://docs.github.com/en/actions/automating-builds-and-tests/building-and-testing-python#publishing-to-package-registries)
